Added topology command-lines.
diff --git a/core/api/src/main/java/org/onlab/onos/net/topology/TopologyService.java b/core/api/src/main/java/org/onlab/onos/net/topology/TopologyService.java
index d8470e7..3469a55 100644
--- a/core/api/src/main/java/org/onlab/onos/net/topology/TopologyService.java
+++ b/core/api/src/main/java/org/onlab/onos/net/topology/TopologyService.java
@@ -2,6 +2,7 @@
 
 import org.onlab.onos.net.ConnectPoint;
 import org.onlab.onos.net.DeviceId;
+import org.onlab.onos.net.Link;
 import org.onlab.onos.net.Path;
 
 import java.util.Set;
@@ -27,6 +28,14 @@
     boolean isLatest(Topology topology);
 
     /**
+     * Returns the graph view of the specified topology.
+     *
+     * @param topology topology descriptor
+     * @return topology graph view
+     */
+    TopologyGraph getGraph(Topology topology);
+
+    /**
      * Returns the set of clusters in the specified topology.
      *
      * @param topology topology descriptor
@@ -35,12 +44,31 @@
     Set<TopologyCluster> getClusters(Topology topology);
 
     /**
-     * Returns the graph view of the specified topology.
+     * Returns the cluster with the specified ID.
      *
      * @param topology topology descriptor
      * @return topology graph view
      */
-    TopologyGraph getGraph(Topology topology);
+    TopologyCluster getCluster(Topology topology, ClusterId clusterId);
+
+    /**
+     * Returns the set of devices that belong to the specified cluster.
+     *
+     * @param topology  topology descriptor
+     * @param cluster topology cluster
+     * @return set of cluster devices
+     */
+    Set<DeviceId> getClusterDevices(Topology topology, TopologyCluster cluster);
+
+    /**
+     * Returns the set of links that form the specified cluster.
+     *
+     * @param topology  topology descriptor
+     * @param cluster topology cluster
+     * @return set of cluster links
+     */
+    Set<Link> getClusterLinks(Topology topology, TopologyCluster cluster);
 
     /**
      * Returns the set of all shortest paths, precomputed in terms of hop-count,
@@ -35,12 +44,31 @@
      *
-     * @param topology topology descriptor
-     * @return topology graph view
+     * @param topology  topology descriptor
+     * @param clusterId cluster identifier
+     * @return topology cluster
      */